@@ -1,7 +1,7 @@
 //muroar.h:
 
 /*
- *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009-2011
+ *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009-2012
  *
  *  This file is part of µRoar,
  *  a minimalist library to access a RoarAudio Sound Server.
@@ -27,6 +27,7 @@
 extern "C" {
 #endif
 
+#ifndef __YIFF__
 // types:
 #include <unistd.h>
 
@@ -34,6 +35,7 @@ extern "C" {
 #ifdef HAVE_HEADER_ENDIAN_H
 #include <endian.h>
 #endif
+#endif
 
 // types of IO:
 #define MUROAR_HDLTYPE_POSIX_SYSIO  1
@@ -44,6 +46,8 @@ extern "C" {
 
 #ifdef __WIN32
 #define MUROAR_HDLTYPE MUROAR_HDLTYPE_WIN32_SOCKET
+#elif defined(__YIFF__)
+#define MUROAR_HDLTYPE MUROAR_HDLTYPE_YIFF_VIO
 #else
 #define MUROAR_HDLTYPE MUROAR_HDLTYPE_POSIX_SYSIO
 #endif
@@ -55,6 +59,15 @@ typedef int muroar_t;
 #include <stdio.h>
 typedef FILE* muroar_t;
 #define MUROAR_HANDLE_INVALID NULL
+#elif MUROAR_HDLTYPE == MUROAR_HDLTYPE_YIFF_VIO
+/* yiff stuff */
+#include <YIFF.h>
+#include <YIFFc/error.h>
+#include <YIFFc/memory.h> /* for stuff like NULL */
+#include <YIFFc/io.h>
+typedef yiffc_vio_t * muroar_t;
+#define MUROAR_HANDLE_INVALID NULL
+#error Unsupported value for MUROAR_HDLTYPE (WIP)
 #else
 #error Unsupported value for MUROAR_HDLTYPE
 #endif
@@ -64,6 +77,9 @@ typedef FILE* muroar_t;
 #define MUROAR_HOST              "localhost"
 #define MUROAR_GSOCK             "/tmp/roar"
 #define MUROAR_OBJECT            "roar"
+#define MUROAR_DEFAULT           "+default"
+#define MUROAR_INVALID           "+invalid"
+#define MUROAR_ABSTRACT          "+abstract"
 
 // AID = Audio Info Defaults
 #define MUROAR_AID_RATE          44100
@@ -186,9 +202,17 @@ typedef FILE* muroar_t;
 
 // muroar.c:
 muroar_t muroar_connect(const char * server, const char * name);
+
+// muroar_close.c:
 int      muroar_close  (muroar_t fh);
+
+// muroar_quit.c:
 int      muroar_quit   (muroar_t fh);
+
+// muroar_beep.c:
 int      muroar_beep   (muroar_t fh);
+
+// muroar_stream.c:
 muroar_t muroar_stream (muroar_t fh, int dir, int * stream, int codec, int rate, int channels, int bits);
 
 // muroario.c:
@@ -198,6 +222,11 @@ ssize_t muroar_read    (muroar_t fh,       void * buf, size_t len);
 // muroar_noop.c:
 int muroar_noop        (muroar_t fh);
 
+// muroar_setvolume.c:
+// We use (long unsigned int) here because we need a portable 16 bit type without <stdint.h>.
+// (long unsigned int) should be big enough on all kind of archs.
+int muroar_setvolume   (muroar_t fh, int stream, long unsigned int left, long unsigned int right);
+
 #ifdef __cplusplus
 }
 #endif
