@@ -1,7 +1,7 @@
 //muroario.c:
 
 /*
- *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009-2011
+ *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009-2012
  *
  *  This file is part of µRoar,
  *  a minimalist library to access a RoarAudio Sound Server.
@@ -25,7 +25,7 @@
 #ifdef __WIN32
 #include <windows.h>
 #include <winsock2.h>
-#else
+#elif !defined(__YIFF__)
 #include <sys/types.h>
 #include <sys/socket.h>
 #endif
@@ -55,6 +55,9 @@ ssize_t muroar_write  (muroar_t fh, const void * buf, size_t len) {
 #elif MUROAR_HDLTYPE == MUROAR_HDLTYPE_POSIX_STDIO
   if ( (ret = fwrite(buf, 1, len, fh)) < 1 )
    return done;
+#elif MUROAR_HDLTYPE == MUROAR_HDLTYPE_YIFF_VIO
+  if ( (ret = yiffc_write(fh, buf, len)) < 1 )
+   return done;
 #else
 #error Unsupported value for MUROAR_HDLTYPE
 #endif
@@ -81,6 +84,9 @@ ssize_t muroar_read   (muroar_t fh,       void * buf, size_t len) {
 #elif MUROAR_HDLTYPE == MUROAR_HDLTYPE_POSIX_STDIO
   if ( (ret = fread(buf, 1, len, fh)) < 1 )
    return done;
+#elif MUROAR_HDLTYPE == MUROAR_HDLTYPE_YIFF_VIO
+  if ( (ret = yiffc_read(fh, buf, len)) < 1 )
+   return done;
 #else
 #error Unsupported value for MUROAR_HDLTYPE
 #endif
